==> syncfusion_flutter_datagrid-18.2.44-beta.tar.gz: lib/src/grid_common/scroll_axis_base/row_column_index.dart <==
part of datagrid;

/// Holds the coordinates for a cell.
class RowColumnIndex {
  int _rowIndex = 0;
  int _columnIndex = 0;

  /// Initializes a new instance of the `RowColumnIndex` struct.
  ///
  /// * rowIndex - _required_ - The row index.
  /// * columnIndex - _required_ - The column index.
  RowColumnIndex(int rowIndex, int columnIndex) {
    this._rowIndex = rowIndex;
    this._columnIndex = columnIndex;
  }

  /// Gets the empty instance with row index and column index set to `int.MinValue`.
  ///
  /// Returns the empty instance with row index and column index set to `int.MinValue`.
  static RowColumnIndex get empty =>
      RowColumnIndex(_MathHelper.maxvalue, _MathHelper.minvalue);

  /// A boolean value indicating whether this instance and a specified object are equal.
  ///
  /// * obj - _required_ - Another object to compare to.
  ///
  /// Returns `True` if obj and this instance are the same type and represent the same value, otherwise `false`.
  bool equals(Object obj) {
    var other = obj as RowColumnIndex;
    return other.rowIndex == this.rowIndex &&
        other.columnIndex == this.columnIndex;
  }

  /// Gets a value indicating whether this instance is empty.
  ///
  /// Returns true if this instance is empty, otherwise false.
  bool get isEmpty => this._rowIndex == _MathHelper.minvalue;

  /// A 32-bit signed integer that is the hash code for this instance.
  ///
  /// Returns the hash code for this instance.
  int getHashCode() {
    return (((this._rowIndex * 2654435761) + this._columnIndex));
  }

  /// The type name with state of this instance.
  ///
  /// Returns the type name with state of this instance.
  @override
  String toString() {
    return '''RowColumnPosition { 
              RowIndex =
              ${this._rowIndex},
              ColumnIndex = 
              ${this._columnIndex} }''';
  }

  /// Gets the column index.
  ///
  /// Returns the column index.
  int get columnIndex => this._columnIndex;

  /// Sets the column index.
  set columnIndex(int value) {
    this.columnIndex = value;
  }

  /// Gets the row index.
  ///
  /// Returns the row index.
  int get rowIndex => this._rowIndex;

  /// Sets the row index.
  set rowIndex(int value) {
    this._rowIndex = value;
  }

  /// Implements the operator == for comparing the given tow row column indexes.
  ///
  /// * rowColumnIndex1 the row column index 1.
  /// * rowColumnIndex2 the row column index 2.
  ///
  /// Returns the comparison result of the operator.
  @override
  bool operator ==(dynamic rowColumnIndex) {
    return this.equals(rowColumnIndex);
  }

  /// Get the hashcode
  ///
  /// Returns the hashcode
  @override
  int get hashCode => super.hashCode;
}

==> syncfusion_flutter_datagrid-18.2.48-beta.tar.gz: lib/src/grid_common/scroll_axis_base/row_column_index.dart <==
part of datagrid;

/// Holds the coordinates for a cell.
class RowColumnIndex {
  int _rowIndex = 0;
  int _columnIndex = 0;

  /// Creates the [RowColumnIndex] to hold coordinates of a cell.
  RowColumnIndex(int rowIndex, int columnIndex) {
    this._rowIndex = rowIndex;
    this._columnIndex = columnIndex;
  }

  /// Creates the empty object with row index and column index set to
  /// `int.MinValue`.
  static RowColumnIndex get empty =>
      RowColumnIndex(_MathHelper.maxvalue, _MathHelper.minvalue);

  /// Whether this object and a specified object are equal.
  bool equals(Object obj) {
    var other = obj as RowColumnIndex;
    return other.rowIndex == this.rowIndex &&
        other.columnIndex == this.columnIndex;
  }

  /// Whether this object is empty.
  ///
  /// Returns true, if this instance is empty, otherwise false.
  bool get isEmpty => this._rowIndex == _MathHelper.minvalue;

  /// A 32-bit signed integer that is the hash code for this object.
  ///
  /// Returns the hash code for this object.
  int getHashCode() {
    return (((this._rowIndex * 2654435761) + this._columnIndex));
  }

  /// The type name with state of this object.
  ///
  /// Returns the type name with state of this object.
  @override
  String toString() {
    return '''RowColumnPosition { 
              RowIndex =
              ${this._rowIndex},
              ColumnIndex = 
              ${this._columnIndex} }''';
  }

  /// An index of a column.
  int get columnIndex => this._columnIndex;

  /// An index of a column.
  set columnIndex(int value) {
    this.columnIndex = value;
  }

  /// An index of a row.
  int get rowIndex => this._rowIndex;

  /// An index of a row.
  set rowIndex(int value) {
    this._rowIndex = value;
  }

  /// Compares the given two row column indexes are equal.
  @override
  bool operator ==(dynamic rowColumnIndex) {
    return this.equals(rowColumnIndex);
  }

  /// The hashcode for this object.
  @override
  int get hashCode => super.hashCode;
}
